-- name: [CS] Nina
-- description: Nina from Antonblast
--[[API Documentation for Character Select can be found below:
https://github.com/Squishy6094/character-select-coop/wiki/API-Documentation]]

--- MODEL ---
local E_MODEL_NINA = smlua_model_util_get_id("nina_geo")

--- ICON ---
local TEX_ICON_NINA = get_texture_info("nina-icon")

--- VOICE ---
local CUSTOM_VOICETABLE_NINA = {
    [CHAR_SOUND_OKEY_DOKEY] =        'NinaStartGame.ogg', -- Starting game
	[CHAR_SOUND_LETS_A_GO] =         'NinaStartLevel.ogg', -- Starting level
	[CHAR_SOUND_PUNCH_YAH] =         'NinaPunch1.ogg', -- Punch 1
	[CHAR_SOUND_PUNCH_WAH] =         'NinaPunch2.ogg', -- Punch 2
	[CHAR_SOUND_PUNCH_HOO] =         'NinaPunch3.ogg', -- Punch 3
	[CHAR_SOUND_YAH_WAH_HOO] =       {'NinaJump1.ogg', 'NinaJump2.ogg', 'NinaJump3.ogg'}, -- First Jump Sounds
	[CHAR_SOUND_HOOHOO] =            'NinaDoubleJump.ogg', -- Second jump sound
	[CHAR_SOUND_YAHOO_WAHA_YIPPEE] = {'NinaTripleJump1.ogg', 'NinaTripleJump2.ogg'}, -- Triple jump sounds
	[CHAR_SOUND_UH] =                'NinaBonk.ogg', -- Wall bonk
	[CHAR_SOUND_UH2] =               'NinaLongJumpLand.ogg', -- Landing after long jump
	[CHAR_SOUND_UH2_2] =             'NinaLongJumpLand2.ogg',
	[CHAR_SOUND_HAHA] =              'NinaTripleJumpLand.ogg', -- Landing triple jump
	[CHAR_SOUND_YAHOO] =             'NinaLongJump.ogg', -- Long jump
	[CHAR_SOUND_DOH] =               'NinaLongJumpBonk.ogg', -- Long jump wall bonk
	[CHAR_SOUND_WHOA] =              'NinaGrabLedge.ogg', -- Grabbing ledge
	[CHAR_SOUND_EEUH] =              'NinaClimbLedge.ogg', -- Climbing over ledge
	[CHAR_SOUND_WAAAOOOW] =          'NinaFalling.ogg', -- Falling a long distance
	[CHAR_SOUND_TWIRL_BOUNCE] =      'NinaFlowerBounce.ogg', -- Bouncing off of a flower spring
	[CHAR_SOUND_GROUND_POUND_WAH] =  'NinaGroundPound.ogg', 
	[CHAR_SOUND_HRMM] =              'NinaLift.ogg', -- Lifting something
	[CHAR_SOUND_HERE_WE_GO] =        'NinaGetStar.ogg', -- Star get
	[CHAR_SOUND_SO_LONGA_BOWSER] =   'NinaThrowBowser.ogg', -- Throwing Bowser
--DAMAGE
	[CHAR_SOUND_ATTACKED] = 'NinaDamaged.ogg', -- Damaged
	[CHAR_SOUND_PANTING] = 'NinaPanting.ogg', -- Low health
	[CHAR_SOUND_ON_FIRE] = 'NinaBurned.ogg', -- Burned
--SLEEP SOUNDS
	[CHAR_SOUND_IMA_TIRED] = 'NinaTired.ogg', -- Mario feeling tired
	[CHAR_SOUND_YAWNING] = 'NinaYawn.ogg', -- Mario yawning before he sits down to sleep
	[CHAR_SOUND_SNORING1] = 'NinaSnore.ogg', -- Snore Inhale
	[CHAR_SOUND_SNORING2] = 'NinaExhale.ogg', -- Exhale
	[CHAR_SOUND_SNORING3] = 'NinaSleepTalk.ogg', -- Sleep talking / mumbling
--COUGHING (USED IN THE GAS MAZE)
	[CHAR_SOUND_COUGHING1] = 'NinaCough1.ogg', -- Cough take 1
	[CHAR_SOUND_COUGHING2] = 'NinaCough2.ogg', -- Cough take 2
	[CHAR_SOUND_COUGHING3] = 'NinaCough3.ogg', -- Cough take 3
--DEATH
	[CHAR_SOUND_DYING] = 'NinaDying.ogg', -- Dying from damage
	[CHAR_SOUND_DROWNING] = 'NinaDrowning.ogg', -- Running out of air underwater
	[CHAR_SOUND_MAMA_MIA] = 'NinaLeaveLevel.ogg' -- Booted out of level
}

--- CHARACTER ---
if _G.charSelectExists then
    -- Add the main character
    local nina_id = _G.charSelect.character_add(
        "Nina",
        {"From Antonblast", " "},
        "TheEnderDwonk",
        {r = 104, g = 81, b = 198},
        E_MODEL_NINA,
        CT_MARIO,
        TEX_ICON_NINA
    )


    -- Add custom voice
    _G.charSelect.character_add_voice(E_MODEL_NINA, CUSTOM_VOICETABLE_NINA)

    -- Hook events for the character's custom behavior
    hook_event(HOOK_CHARACTER_SOUND, function(m, sound)
        if _G.charSelect.character_get_voice(m) == CUSTOM_VOICETABLE_NINA then
            return _G.charSelect.voice.sound(m, sound)
        end
    end)

    hook_event(HOOK_MARIO_UPDATE, function(m)
        if _G.charSelect.character_get_voice(m) == CUSTOM_VOICETABLE_NINA then
            return _G.charSelect.voice.snore(m)
        end
    end)
end
